==> tuia-explore-center-api-0.0.1-20190528.070415-11-sources.jar: cn/tuia/explore/center/api/dto/req/LoginDto.java <==
package cn.tuia.explore.center.api.dto.req;

import java.io.Serializable;

/**
 * @author ZhouFeng zhoufeng@duiba.com.cn
 * @version $Id: LoginDto.java , v 0.1 2017/12/28 下午2:37 ZhouFeng Exp $
 */
public class LoginDto<T extends LoginAuthDto> implements Serializable {

    private static final long serialVersionUID = 1890955652773620573L;
    /**
     * 身份验证参数
     */
    @SuppressWarnings({"squid:S1948"})
    private T authDto;

    /**
     * 设备号
     */
    private String deviceId;

    /**
     * 电子串号
     */
    private String iemi;

    /**
     * 手机号
     */
    private String phoneNum;

    /**
     * 用户昵称
     */
    private String nickName;

    /**
     * 用户头像
     */
    private String headImage;

    /**
     * 登陆版本号
     */
    private String currentVersion;


    public T getAuthDto() {
        return authDto;
    }

    public void setAuthDto(T authDto) {
        this.authDto = authDto;
    }

    public String getDeviceId() {
        return deviceId;
    }

    public void setDeviceId(String deviceId) {
        this.deviceId = deviceId;
    }

    public String getIemi() {
        return iemi;
    }

    public void setIemi(String iemi) {
        this.iemi = iemi;
    }

    public String getPhoneNum() {
        return phoneNum;
    }

    public void setPhoneNum(String phoneNum) {
        this.phoneNum = phoneNum;
    }

    public String getNickName() {
        return nickName;
    }

    public void setNickName(String nickName) {
        this.nickName = nickName;
    }

    public String getHeadImage() {
        return headImage;
    }

    public void setHeadImage(String headImage) {
        this.headImage = headImage;
    }

    public String getCurrentVersion() {
        return currentVersion;
    }

    public void setCurrentVersion(String currentVersion) {
        this.currentVersion = currentVersion;
    }
}

==> tuia-explore-center-api-0.4.0-20190702.064846-13-sources.jar: cn/tuia/explore/center/api/dto/req/LoginDto.java <==
package cn.tuia.explore.center.api.dto.req;

import java.io.Serializable;

/**
 * @author ZhouFeng zhoufeng@duiba.com.cn
 * @version $Id: LoginDto.java , v 0.1 2017/12/28 下午2:37 ZhouFeng Exp $
 */
public class LoginDto<T extends LoginAuthDto> implements Serializable {

    private static final long serialVersionUID = 1890955652773620573L;
    /**
     * 身份验证参数
     */
    @SuppressWarnings({"squid:S1948"})
    private T authDto;

    /**
     * 设备号
     */
    private String deviceId;

    /**
     * 电子串号
     */
    private String iemi;

    /**
     * 手机号
     */
    private String phoneNum;

    /**
     * 用户昵称
     */
    private String nickName;

    /**
     * 用户头像
     */
    private String headImage;

    /**
     * 登陆版本号
     */
    private String currentVersion;

    /**
     * 性别 0:保密 1：男 2：女
     */
    private Integer sex;


    public T getAuthDto() {
        return authDto;
    }

    public void setAuthDto(T authDto) {
        this.authDto = authDto;
    }

    public String getDeviceId() {
        return deviceId;
    }

    public void setDeviceId(String deviceId) {
        this.deviceId = deviceId;
    }

    public String getIemi() {
        return iemi;
    }

    public void setIemi(String iemi) {
        this.iemi = iemi;
    }

    public String getPhoneNum() {
        return phoneNum;
    }

    public void setPhoneNum(String phoneNum) {
        this.phoneNum = phoneNum;
    }

    public String getNickName() {
        return nickName;
    }

    public void setNickName(String nickName) {
        this.nickName = nickName;
    }

    public String getHeadImage() {
        return headImage;
    }

    public void setHeadImage(String headImage) {
        this.headImage = headImage;
    }

    public String getCurrentVersion() {
        return currentVersion;
    }

    public void setCurrentVersion(String currentVersion) {
        this.currentVersion = currentVersion;
    }

    public Integer getSex() {
        return sex;
    }

    public void setSex(Integer sex) {
        this.sex = sex;
    }
}
